==> zio-aws-amplifyuibuilder_2.12-5.17.104.9-sources.jar: zio/aws/amplifyuibuilder/model/CreateThemeResponse.scala <==
package zio.aws.amplifyuibuilder.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateThemeResponse(
    entity: Option[zio.aws.amplifyuibuilder.model.Theme] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifyuibuilder.model.CreateThemeResponse = {
    import CreateThemeResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifyuibuilder.model.CreateThemeResponse
      .builder()
      .optionallyWith(entity.map(value => value.buildAwsValue()))(_.entity)
      .build()
  }
  def asReadOnly: zio.aws.amplifyuibuilder.model.CreateThemeResponse.ReadOnly =
    zio.aws.amplifyuibuilder.model.CreateThemeResponse.wrap(buildAwsValue())
}
object CreateThemeResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifyuibuilder.model.CreateThemeResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifyuibuilder.model.CreateThemeResponse =
      zio.aws.amplifyuibuilder.model
        .CreateThemeResponse(entity.map(value => value.asEditable))
    def entity: Option[zio.aws.amplifyuibuilder.model.Theme.ReadOnly]
    def getEntity
        : ZIO[Any, AwsError, zio.aws.amplifyuibuilder.model.Theme.ReadOnly] =
      AwsError.unwrapOptionField("entity", entity)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifyuibuilder.model.CreateThemeResponse
  ) extends zio.aws.amplifyuibuilder.model.CreateThemeResponse.ReadOnly {
    override val entity: Option[zio.aws.amplifyuibuilder.model.Theme.ReadOnly] =
      scala
        .Option(impl.entity())
        .map(value => zio.aws.amplifyuibuilder.model.Theme.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifyuibuilder.model.CreateThemeResponse
  ): zio.aws.amplifyuibuilder.model.CreateThemeResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-amplifyuibuilder_2.13-5.19.31.3-sources.jar: zio/aws/amplifyuibuilder/model/CreateThemeResponse.scala <==
package zio.aws.amplifyuibuilder.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateThemeResponse(
    entity: Optional[zio.aws.amplifyuibuilder.model.Theme] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifyuibuilder.model.CreateThemeResponse = {
    import CreateThemeResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifyuibuilder.model.CreateThemeResponse
      .builder()
      .optionallyWith(entity.map(value => value.buildAwsValue()))(_.entity)
      .build()
  }
  def asReadOnly: zio.aws.amplifyuibuilder.model.CreateThemeResponse.ReadOnly =
    zio.aws.amplifyuibuilder.model.CreateThemeResponse.wrap(buildAwsValue())
}
object CreateThemeResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifyuibuilder.model.CreateThemeResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifyuibuilder.model.CreateThemeResponse =
      zio.aws.amplifyuibuilder.model
        .CreateThemeResponse(entity.map(value => value.asEditable))
    def entity: Optional[zio.aws.amplifyuibuilder.model.Theme.ReadOnly]
    def getEntity
        : ZIO[Any, AwsError, zio.aws.amplifyuibuilder.model.Theme.ReadOnly] =
      AwsError.unwrapOptionField("entity", entity)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifyuibuilder.model.CreateThemeResponse
  ) extends zio.aws.amplifyuibuilder.model.CreateThemeResponse.ReadOnly {
    override val entity
        : Optional[zio.aws.amplifyuibuilder.model.Theme.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.entity())
        .map(value => zio.aws.amplifyuibuilder.model.Theme.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifyuibuilder.model.CreateThemeResponse
  ): zio.aws.amplifyuibuilder.model.CreateThemeResponse.ReadOnly = new Wrapper(
    impl
  )
}
